# Parameter Optimisation by Iterative Spectral Evaluation

[![Documentation Status](https://readthedocs.org/projects/nmrpoise/badge/?version=latest)](https://nmrpoise.readthedocs.io/en/latest/?badge=latest)
[![Travis CI Build Status](https://travis-ci.com/foroozandehgroup/nmrpoise.svg?branch=master)](https://travis-ci.com/github/foroozandehgroup/nmrpoise)
[![PyPI version](https://badge.fury.io/py/nmrpoise.svg)](https://badge.fury.io/py/nmrpoise)

POISE is a Python package for the numerical optimisation of NMR parameters.
The frontend runs in Bruker's TopSpin software, and is connected to a Python 3 backend.

POISE can be installed using ``pip``:

    pip install nmrpoise

Documentation is hosted at https://nmrpoise.readthedocs.io/.
